@@ -1,4 +1,5 @@
-/* GnomeMeeting -- A Video-Conferencing application
+
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -12,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -92,30 +93,6 @@ GnomeMeeting::GnomeMeeting ()
 GnomeMeeting::~GnomeMeeting()
 { 
   Exit ();
-
-  if (addressbook_window) 
-    gtk_widget_destroy (addressbook_window);  
-  if (prefs_window)
-    gtk_widget_destroy (prefs_window);
-  if (pc2phone_window)
-    gtk_widget_destroy (pc2phone_window);
-  if (history_window)
-    gtk_widget_destroy (history_window);
-  if (calls_history_window)
-    gtk_widget_destroy (calls_history_window);
-  if (main_window)
-    gtk_widget_destroy (main_window);
-  if (druid_window)
-    gtk_widget_destroy (druid_window);
-  if (accounts_window)
-    gtk_widget_destroy (accounts_window);
-  if (chat_window)
-    gtk_widget_destroy (chat_window);
-  if (statusicon)
-    gtk_widget_destroy (statusicon);
-#ifdef HAS_DBUS
-    g_object_unref (dbus_component);
-#endif
 }
 
 
@@ -184,43 +161,124 @@ GnomeMeeting::Init ()
 void
 GnomeMeeting::Exit ()
 {
-  PWaitAndSignal m(ep_var_mutex);
-
   RemoveManager ();
+
+  if (addressbook_window) 
+    gtk_widget_destroy (addressbook_window);  
+  addressbook_window = NULL;
+  
+  if (prefs_window)
+    gtk_widget_destroy (prefs_window);
+  prefs_window = NULL;
+  
+  if (pc2phone_window)
+    gtk_widget_destroy (pc2phone_window);
+  pc2phone_window = NULL;
+  
+  if (history_window)
+    gtk_widget_destroy (history_window);
+  history_window = NULL;
+  
+  if (main_window)
+    gtk_widget_destroy (main_window);
+  main_window = NULL;
+  
+  if (druid_window)
+    gtk_widget_destroy (druid_window);
+  druid_window = NULL;
+  
+  if (accounts_window)
+    gtk_widget_destroy (accounts_window);
+  accounts_window = NULL;
+  
+  if (chat_window)
+    gtk_widget_destroy (chat_window);
+  chat_window = NULL;
+  
+  if (statusicon)
+    gtk_widget_destroy (statusicon);
+  statusicon = NULL;
+  
+#ifdef HAS_DBUS
+  if (dbus_component)
+    g_object_unref (dbus_component);
+  dbus_component = NULL;
+#endif
 }
 
 
 BOOL
 GnomeMeeting::DetectInterfaces ()
 {
+  PString config_interface;
+  PString iface_noip;
+  PString ip;
   PIPSocket::InterfaceTable ifaces;
 
   PINDEX i = 0;
+  PINDEX pos = 0;
   BOOL res = FALSE;
+
+  gchar *conf_interface = NULL;
   
   PWaitAndSignal m(iface_access_mutex);
   
   /* Detect the valid interfaces */
   res = PIPSocket::GetInterfaceTable (ifaces);
-
+  interfaces.RemoveAll ();
+  
+  conf_interface = gm_conf_get_string (PROTOCOLS_KEY "interface");
+  config_interface = conf_interface;
+  g_free (conf_interface);
+  
+  pos = config_interface.Find("[");
+  if (pos != P_MAX_INDEX)
+    iface_noip = config_interface.Left (pos).Trim ();
   while (i < ifaces.GetSize ()) {
     
-    if (ifaces [i].GetName ().Find ("ppp") != P_MAX_INDEX) {
+    ip = " [" + ifaces [i].GetAddress ().AsString () + "]";
+    
+    if (ifaces [i].GetName () + ip == config_interface || ifaces [i].GetName () == iface_noip) 
+      break;
       
-      if (i > 0) {
-	interfaces += interfaces [0];
-	interfaces [0] = ifaces [i].GetName ();
+    i++;
+  }
+
+  pos = i;
+  i = 0;
+
+  while (i < ifaces.GetSize ()) {
+
+    ip = " [" + ifaces [i].GetAddress ().AsString () + "]";
+
+    if (i != pos) {
+
+      if (ifaces [i].GetAddress ().AsString () != "0.0.0.0") {
+
+        if (ifaces [i].GetName ().Find ("ppp") != P_MAX_INDEX) {
+
+          if (i > 0) {
+            interfaces += interfaces [0];
+            interfaces [0] = ifaces [i].GetName () + ip;     
+          }
+          else
+            interfaces += ifaces [i].GetName () + ip;
+        }
+        else if (ifaces [i].GetName () != "lo"
+                 && ifaces [i].GetName () != "MS TCP Loopback interface")
+          interfaces += ifaces [i].GetName () + ip;
       }
-      else
-	interfaces += ifaces [i].GetName ();
     }
-    else if (ifaces [i].GetName () != "lo"
-	&& ifaces [i].GetName () != "MS TCP Loopback interface")
-      interfaces += ifaces [i].GetName ();
+    else {
+
+      if (!interfaces [0].IsEmpty ())
+        interfaces += interfaces [0];
+      interfaces [0] = ifaces [pos].GetName () + ip;
+    }
     
     i++;
   }
-  
+
   
   /* Update the GUI, if it is already there */
   if (prefs_window)
@@ -229,7 +287,7 @@ GnomeMeeting::DetectInterfaces ()
   
   return res;
 }
-  
+
 
 BOOL
 GnomeMeeting::DetectDevices ()
@@ -450,8 +508,8 @@ void GnomeMeeting::BuildGUI ()
   prefs_window = gm_prefs_window_new ();  
   calls_history_window = gm_calls_history_window_new ();
   history_window = gm_history_window_new ();
-  addressbook_window = gm_addressbook_window_new ();
   chat_window = gm_text_chat_window_new ();
+  addressbook_window = gm_addressbook_window_new ();
   druid_window = gm_druid_window_new ();
   accounts_window = gm_accounts_window_new ();
   main_window = gm_main_window_new ();
@@ -473,9 +531,9 @@ void GnomeMeeting::BuildGUI ()
 			    MAJOR_VERSION, MINOR_VERSION, BUILD_NUMBER,
 			    g_get_user_name ());
 
-  PTRACE (1, "GnomeMeeting version "
+  PTRACE (1, "Ekiga version "
 	  << MAJOR_VERSION << "." << MINOR_VERSION << "." << BUILD_NUMBER);
-  PTRACE (1, "OPAL version " << "unknown");
+  PTRACE (1, "OPAL version " << OPAL_VERSION);
   PTRACE (1, "PWLIB version " << PWLIB_VERSION);
 #ifndef DISABLE_GNOME
   PTRACE (1, "GNOME support enabled");
